@@ -19,6 +19,7 @@ from typing import List, Union, Tuple, Optional
 from deeppavlov.core.common.chainer import Chainer
 from deeppavlov.core.common.registry import register
 from deeppavlov.core.models.estimator import Component
+from deeppavlov.models.doc_retrieval.utils import find_answer_sentence
 
 logger = getLogger(__name__)
 
@@ -42,11 +43,12 @@ class LogitRanker(Component):
     """
 
     def __init__(self, squad_model: Union[Chainer, Component], batch_size: int = 50,
-                 sort_noans: bool = False, top_n: int = 1, **kwargs):
+                 sort_noans: bool = False, top_n: int = 1, return_answer_sentence: bool = False, **kwargs):
         self.squad_model = squad_model
         self.batch_size = batch_size
         self.sort_noans = sort_noans
         self.top_n = top_n
+        self.return_answer_sentence = return_answer_sentence
 
     def __call__(self, contexts_batch: List[List[str]], questions_batch: List[List[str]],
                  doc_ids_batch: Optional[List[List[str]]] = None) -> \
@@ -55,7 +57,7 @@ class LogitRanker(Component):
                 Tuple[List[List[str]], List[List[float]], List[List[int]], List[List[str]]],
                 Tuple[List[str], List[float], List[int]],
                 Tuple[List[List[str]], List[List[float]], List[List[int]]]
-                ]:
+            ]:
 
         """
         Sort obtained results from squad reader by logits and get the answer with a maximum logit.
@@ -76,20 +78,31 @@ class LogitRanker(Component):
         batch_best_answers_score = []
         batch_best_answers_place = []
         batch_best_answers_doc_ids = []
+        batch_best_answers_sentences = []
         for quest_ind, [contexts, questions] in enumerate(zip(contexts_batch, questions_batch)):
             results = []
             for i in range(0, len(contexts), self.batch_size):
                 c_batch = contexts[i: i + self.batch_size]
                 q_batch = questions[i: i + self.batch_size]
-                batch_predict = zip(*self.squad_model(c_batch, q_batch))
+                batch_predict = list(zip(*self.squad_model(c_batch, q_batch), c_batch))
                 results += batch_predict
             if self.sort_noans:
                 results_sort = sorted(results, key=lambda x: (x[0] != '', x[2]), reverse=True)
             else:
                 results_sort = sorted(results, key=itemgetter(2), reverse=True)
-            batch_best_answers.append([x[0] for x in results_sort[:self.top_n]])
-            batch_best_answers_place.append([x[1] for x in results_sort[:self.top_n]])
-            batch_best_answers_score.append([x[2] for x in results_sort[:self.top_n]])
+            best_answers = [x[0] for x in results_sort[:self.top_n]]
+            best_answers_place = [x[1] for x in results_sort[:self.top_n]]
+            best_answers_score = [x[2] for x in results_sort[:self.top_n]]
+            best_answers_contexts = [x[3] for x in results_sort[:self.top_n]]
+            batch_best_answers.append(best_answers)
+            batch_best_answers_place.append(best_answers_place)
+            batch_best_answers_score.append(best_answers_score)
+            best_answers_sentences = []
+            for answer, place, context in zip(best_answers, best_answers_place, best_answers_contexts):
+                sentence = find_answer_sentence(place, context)
+                best_answers_sentences.append(sentence)
+            batch_best_answers_sentences.append(best_answers_sentences)
+
             if doc_ids_batch is not None:
                 doc_ind = [results.index(x) for x in results_sort]
                 batch_best_answers_doc_ids.append(
@@ -100,8 +113,15 @@ class LogitRanker(Component):
             batch_best_answers_place = [x[0] for x in batch_best_answers_place]
             batch_best_answers_score = [x[0] for x in batch_best_answers_score]
             batch_best_answers_doc_ids = [x[0] for x in batch_best_answers_doc_ids]
+            batch_best_answers_sentences = [x[0] for x in batch_best_answers_sentences]
 
         if doc_ids_batch is None:
+            if self.return_answer_sentence:
+                return batch_best_answers, batch_best_answers_score, batch_best_answers_place, \
+                       batch_best_answers_sentences
             return batch_best_answers, batch_best_answers_score, batch_best_answers_place
 
+        if self.return_answer_sentence:
+            return batch_best_answers, batch_best_answers_score, batch_best_answers_place, batch_best_answers_doc_ids, \
+                   batch_best_answers_sentences
         return batch_best_answers, batch_best_answers_score, batch_best_answers_place, batch_best_answers_doc_ids
